# eric7.Debugger.ExceptionLogger

Module implementing the Exception Logger widget.

### Global Attributes

None

### Classes

ExceptionLogger | Class implementing the Exception Logger widget.

### Functions

None

## ExceptionLogger

Class implementing the Exception Logger widget.

This class displays a log of all exceptions having occured during a debugging session.

### Signals

sourceFile(string, int)
  emitted to open a source file at a line

### Derived from

QTreeWidget

### Class Attributes

None

### Class Methods

None

### Methods

ExceptionLogger | Constructor
__configure | Private method to open the configuration dialog.
__itemDoubleClicked | Private slot to handle the double click of an item.
__openSource | Private slot to handle a double click on an entry.
__showContextMenu | Private slot to show the context menu of the view.
addException | Public slot to handle the arrival of a new exception.
debuggingStarted | Public slot to clear the listview upon starting a new debugging session.

### Static Methods

None

#### ExceptionLogger (Constructor)

ExceptionLogger(parent=None)

Constructor

parent (QWidget)
  reference to the parent widget

#### ExceptionLogger.__configure

__configure()

Private method to open the configuration dialog.

#### ExceptionLogger.__itemDoubleClicked

__itemDoubleClicked(itm)

Private slot to handle the double click of an item.

itm (QTreeWidgetItem)
  reference to the item that was double clicked (ignored)

#### ExceptionLogger.__openSource

__openSource()

Private slot to handle a double click on an entry.

#### ExceptionLogger.__showContextMenu

__showContextMenu(coord)

Private slot to show the context menu of the view.

coord (QPoint)
  global coordinates of the mouse pointer

#### ExceptionLogger.addException

addException(exceptionType, exceptionMessage, stackTrace, debuggerId)

Public slot to handle the arrival of a new exception.

exceptionType (str)
  type of exception raised
exceptionMessage (str)
  message given by the exception
stackTrace (list)
  list of stack entries
debuggerId (str)
  ID of the debugger backend

#### ExceptionLogger.debuggingStarted

debuggingStarted()

Public slot to clear the listview upon starting a new debugging session.

Up